pytilities.aop.aspects.view — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »
- pytilities.aop.aspects »

# pytilities.aop.aspects.view

`pytilities.aop.aspects.view.` `create_view`(aspect)

  Create a View class.

  Instances of the view delegate all access to an inner object. Before delegating they enable the given aspect, at the end of the access the aspect is disabled.

  Parameters: | aspect (Aspect) – The aspect to enable during viewing, and disable otherwise

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »
- pytilities.aop.aspects »